@@ -118,23 +118,20 @@ class JobHandler():
                 'from training script: {}.py'.format(model_name, script_name_noext))
         return model
 
-    def save_metadata(self, df, summary={}):
-        hyperparameters = {key:key.replace('config/','') for key in df if 'config/' in key}
-        df = df.rename(columns=hyperparameters)
+    def save_metadata(self, df, summary):
+        hyperparameters = summary['hyperparameters']
+        rename_hp = { 'config/{}'.format(hp): hp for hp in hyperparameters}
+        df = df.rename(columns=rename_hp)
         df = df.rename(columns={'time_total_s':'time_s'})
-        hp_raw = list(hyperparameters.keys())
-        hp = list(hyperparameters.values())
-        columns_to_save = ['time_s']
-        columns_to_save.extend(hp)
+        columns_to_save = ['time_s'] + hyperparameters
         if 'metric' in summary:
             columns_to_save.append(summary['metric'])
         df = df.filter(columns_to_save, axis=1).transpose()
         result = df.to_dict()
         summary['result'] = result
-        summary['hyperparameters'] = hp
 
         with open(kGridSiteMetadataFileName,'w') as output:
-            json.dump(summary, output)
+            json.dump(summary, output, cls=helper.NpEncoder)
 
     @staticmethod
     def get_resource_info():
@@ -214,6 +211,7 @@ class JobHandler():
             'start_date_time': start_data_time,
             'end_date_time': end_data_time,
             'task_time_s' : total_time,
+            'hyperparameters': list(search_space.keys()),
             'metric': hpo_config['metric'],
             'mode' : hpo_config['mode'],
             'best_config' : best_config, 
