@@ -10,7 +10,7 @@ kiDDSHPoutput = 'output.json'
 
 kAlgoMap = {
     'random': 'tune',
-    'bayesian': 'skopt'
+    'bayesian': 'hyperopt'
 }
 
 kSearchAlgorithms = ['hyperopt', 'skopt', 'bohb', 'ax', 'tune', 'random', 'grid', 'bayesian', 'nevergrad']
