@@ -49,7 +49,23 @@ class JobBuilder():
         if value not in kMetricMode:
             raise ValueError('metric mode must be either "min" or "max"')
         self._mode = value
+        
+    @property
+    def resource(self):
+        return self._resource
+    
+    @resource.setter
+    def resource(self, value):
+        resource = JobBuilder.get_resource_info()
+        if isinstance(value, dict):
+            for device in ['cpu', 'gpu']:
+                if device in value and value[device]:
+                    resource[device] = min(value[device], resource[device])
+        print('INFO: Each trial will use {} GPU(s) resource'.format(resource['gpu']))
+        print('INFO: Each trial will use {} CPU(s) resource'.format(resource['cpu']))
+        self._resource = resource
 
+        
     @property
     def df(self) -> 'pandas.DataFrame':
         return self._df
@@ -77,8 +93,8 @@ class JobBuilder():
     @property
     def hyperparameters(self):
         return self._hyperparameters
-    
-    
+
+
     def reset(self):
         self.project_name = None
         # model configuration
@@ -99,6 +115,7 @@ class JobBuilder():
         self.verbose = False
         self.log_dir = kDefaultLogDir
         self.stop = kDefaultStopping
+        self._resource = None
         # parameters for logging
         self._df = None
         self._start_datetime = None
@@ -231,14 +248,8 @@ class JobBuilder():
         n_cpu = helper.get_n_cpu()
         print('INFO: Number of GPUs detected: ',n_gpu)
         print('INFO: Number of CPUs detected: ',n_cpu)
-        if n_gpu > 0:
-            resource['gpu'] = n_gpu
-            print('INFO: Each trial will use {} GPU(s) resource'.format(n_gpu))
-        if n_cpu > 0:
-            resource['cpu'] = n_cpu
-            print('INFO: Each trial will use {} CPU(s) resource'.format(n_cpu))
-        if not resource:
-            resource = None
+        resource['gpu'] = n_gpu
+        resource['cpu'] = n_cpu
         return resource
     
     def run(self) -> None:
@@ -268,8 +279,6 @@ class JobBuilder():
             self.search_space,
             **self.scheduler_param)
 
-        resources_per_trial = JobBuilder.get_resource_info()
-
         model = JobBuilder.get_model(self.model_script, self.model_name)
 
         self._start_datetime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
@@ -289,7 +298,7 @@ class JobBuilder():
                 search_alg=algorithm,
                 config=tune_config_space,
                 num_samples=self.num_trials,
-                resources_per_trial=resources_per_trial,
+                resources_per_trial=self.resource,
                 verbose=self.verbose,
                 local_dir=self.log_dir,
                 stop=self.stop,
@@ -404,6 +413,7 @@ class JobBuilder():
         job.verbose = config['hpo_config']['verbose']
         job.log_dir = config['hpo_config']['log_dir']
         job.stop = config['hpo_config']['stop']
+        job.resource = config['hpo_config']['resource']
         
         # Load model configuration
         job.model_script = config['model_config']['script']
@@ -425,6 +435,7 @@ def local_job_parser(idds_job=False):
     job.run()
             
 def grid_job_parser(idds_job=False):
+    extracted_files = []
     try:
         extracted_files = helper.extract_tarball(kDataDir, kDataDir)
         helper.grid_site_setup()
