@@ -106,11 +106,9 @@ class ProjectConfiguration(ConfigurationBase):
         # create project directories
         scripts_dir = os.path.join(proj_path, 'scripts')
         config_dir = os.path.join(proj_path, 'config')
-        idds_dir = os.path.join(proj_path, 'idds')
         os.makedirs(proj_path, exist_ok=True)        
         os.makedirs(scripts_dir, exist_ok=True)
         os.makedirs(config_dir, exist_ok=True)
-        os.makedirs(idds_dir, exist_ok=True)
 
         # copy training scripts to the project directory
         if ('scripts_path' in config) and (config['scripts_path'] is not None):
@@ -134,8 +132,6 @@ class ProjectConfiguration(ConfigurationBase):
     
         project_config_path_json = os.path.join(config_dir, kProjectConfigNameJson)
         project_config_path_yaml = os.path.join(config_dir, kProjectConfigNameYaml)
-        idds_config_path = os.path.join(idds_dir, kiDDSConfigName)
-        idds_search_space_path = os.path.join(idds_dir, kiDDSSearchSpaceName)
         
         with open(project_config_path_json,'w') as proj_config_file:
             json.dump(project_config, proj_config_file, indent=2)
@@ -143,16 +139,21 @@ class ProjectConfiguration(ConfigurationBase):
         with open(project_config_path_yaml,'w') as proj_config_file:
             yaml.dump(project_config, proj_config_file, default_flow_style=False, sort_keys=False)
             print('INFO: Created project configuration: {}'.format(project_config_path_yaml))
-        
+            
+        search_space = project_config['search_space']    
+        idds_search_space_path = os.path.join(config_dir, kiDDSSearchSpaceName)
+        with open(idds_search_space_path, 'w') as idds_search_space_file:
+            json.dump(search_space, idds_search_space_file)
+            print('INFO: Created iDDS search space file: {}'.format(idds_search_space_path))
+            
+        '''
         # save configurations for idds workflow
+        idds_config_path = os.path.join(idds_dir, kiDDSConfigName)
         idds_config = self.to_idds_config(project_config)
         with open(idds_config_path, 'w') as idds_config_file:
             json.dump(idds_config, idds_config_file, indent=2)
             print('INFO: Created iDDS configuration: {}'.format(idds_config_path))
-        search_space = project_config['search_space']
-        with open(idds_search_space_path, 'w') as idds_search_space_file:
-            json.dump(search_space, idds_search_space_file)
-            print('INFO: Created iDDS search space file: {}'.format(idds_search_space_path))
+        '''
         '''
         for key in kConfigList:
             if (key in config) and (config[key] is not None):
@@ -168,7 +169,8 @@ class ProjectConfiguration(ConfigurationBase):
         with open(project_config_path,'w') as proj_config_file:
             json.dump(project_config, proj_config_file, indent=2)
         '''
-        
+    
+    '''
     # subject to updates
     @staticmethod
     def to_idds_config(config):
@@ -177,7 +179,8 @@ class ProjectConfiguration(ConfigurationBase):
         library = config['hpo_config']['algorithm']
         method = config['hpo_config']['algorithm_param'].get('method', None)
         in_ds = config['grid_config']['inDS']
-        
+        max_concurrent = config['hpo_config']['max_concurrent']
+        max_point = config['hpo_config']['num_trials']
         idds_config = {}
         generator_options = {}
         generator_options['n_point'] = '%NUM_POINTS'
@@ -196,10 +199,12 @@ class ProjectConfiguration(ConfigurationBase):
         idds_config['evaluationInput'] = kiDDSHPinput
         idds_config['evaluationOutput'] = kiDDSHPoutput
         idds_config['evaluationMeta'] = kGridSiteMetadataFileName
-        idds_config['nParallelEvaluation'] = config['hpo_config']['max_concurrent']
+        idds_config['nParallelEvaluation'] = max_concurrent
+        idds_config['maxPoints'] = max_point
         idds_config['trainingDS'] = in_ds        
 
         return idds_config
+    '''
     
     def get_config_list(self, expr=None):
         project_list = [ s for s in super().get_config_list() if s is not 'backup']
