@@ -4,6 +4,7 @@ import json
 
 from hpogrid.components.defaults import *
 from hpogrid.components import validation
+from hpogrid.utils import stylus
 from hpogrid.configuration.configuration_base import ConfigurationBase, kConfigAction
 
 class SearchSpaceConfiguration(ConfigurationBase):
@@ -49,6 +50,8 @@ class SearchSpaceConfiguration(ConfigurationBase):
         if validation.validate_search_space(search_space):
             self.save(search_space, config_name, action)
         return search_space
-
-    def show(self, name, yaml_depth=1):
-        super().show(name, yaml_depth)
\ No newline at end of file
+    
+    def show(self, name):
+        config = self.load_config(name)
+        table = stylus.create_formated_dict(config, self.show_columns, indexed=False)
+        print(table)    
\ No newline at end of file
